data:extend({
    {
        type = "locomotive",
        name = "JunkTrain",
        icon = "__JunkTrain__/graphics/train.png",
        flags = {"placeable-neutral", "player-creation", "placeable-off-grid", "not-on-map"},
        minable = {mining_time = 1, result = "JunkTrain"},
        mined_sound = {filename = "__core__/sound/deconstruct-medium.ogg"},
        max_health = 100,
        corpse = "medium-remnants",
        dying_explosion = "medium-explosion",
        wheels = standard_train_wheels,
		connection_distance = 3.4,
		joint_distance = 3.2,
		collision_box = {{-0.6, -2.0}, {0.6, 2.0}},
		selection_box = {{-0.85, -1.5}, {0.9, 1.5}},
		vertical_selection_shift = -0.5,
        drawing_box = {{-1, -4}, {1, 3}},
        weight = 2500,
        max_speed = 0.3,
        max_power = "300kW",
        reversing_power_modifier = 0.8,
        braking_force = 20,
        friction_force = 0.50,
        -- this is a percentage of current speed that will be subtracted
        air_resistance = 0.03,
        energy_per_hit_point = 5,
        resistances =
        {
            {
                type = "fire",
                decrease = 3,
                percent = 10
            },
        },
        energy_source =
        {
            type = "burner",
            effectivity = 0.3,
            fuel_inventory_size = 1,
            smoke =
            {
                {
                    name = "train-smoke",
                    deviation = {0.3, 0.3},
                    frequency = 150,
                    position = {0.4, 0},
                    starting_frame = 0,
                    starting_frame_deviation = 20,
                    height = 2,
                    height_deviation = 0.5,
                    starting_vertical_speed = 0.01,
                    starting_vertical_speed_deviation = 0.1,
                }
            }
        },
        front_light =
        {
            {
                type = "oriented",
                minimum_darkness = 0.3,
                picture =
                {
                    filename = "__core__/graphics/light-cone.png",
                    priority = "medium",
                    scale = 2,
                    width = 200,
                    height = 200
                },
                shift = {-0.6, -16},
                size = 2,
                intensity = 0.6
            },
            {
                type = "oriented",
                minimum_darkness = 0.3,
                picture =
                {
                    filename = "__core__/graphics/light-cone.png",
                    priority = "medium",
                    scale = 2,
                    width = 200,
                    height = 200
                },
                shift = {0.6, -16},
                size = 2,
                intensity = 0.6
            }
        },
        back_light = rolling_stock_back_light(),
        stand_by_light = rolling_stock_stand_by_light(),
        color = {r = 0.07, g = 0.92, b = 0, a = 0.5},
        pictures =
        {
			
            layers =
            {
                
                {
                    priority = "very-low",
                    width = 256,
                    height = 256,
                    direction_count = 128,
                    filenames =
                    {
                        "__JunkTrain__/graphics/loco1.png",
						"__JunkTrain__/graphics/loco2.png",
                    },
                    line_length = 8,
                    lines_per_file = 8,
                    shift = {0.4, -1.125}
                }
            }
        },
        rail_category = "regular",
        stop_trigger =
        {
            -- left side
         
            -- right side
            {
                type = "create-smoke",
                repeat_count = 25,
                entity_name = "smoke-train-stop",
                initial_height = 0,
                -- smoke goes to the right
                speed = {0.001, 0},
                speed_multiplier = 0.05,
                speed_multiplier_deviation = 1.2,
                offset_deviation = {{0.6, -2.7}, {0.75, 2.7}}
            },
            {
                type = "play-sound",
                sound =
                {
                    {
                        filename = "__base__/sound/train-breaks.ogg",
                        volume = 0.6
                    },
                }
            },
        },
        drive_over_tie_trigger = drive_over_tie(),
        tie_distance = 50,
        vehicle_impact_sound =  { filename = "__base__/sound/car-metal-impact.ogg", volume = 0.65 },
        working_sound =
        {
            sound =
            {
                filename = "__base__/sound/train-engine.ogg",
                volume = 0.4
            },
            match_speed_to_activity = true,
        },
        open_sound = { filename = "__base__/sound/car-door-open.ogg", volume=0.7 },
        close_sound = { filename = "__base__/sound/car-door-close.ogg", volume = 0.7 },
        sound_minimum_speed = 0.5;
    },
	{
		type = "straight-rail",
		name = "straight-scrap-rail",
		icon = "__base__/graphics/icons/rail.png",
		flags = {"placeable-neutral", "player-creation", "building-direction-8-way"},
		minable = {mining_time = 0.2, result = "scrap-rail"},
		max_health = 10,
		corpse = "straight-rail-remnants",
		resistances =
    {
      {
        type = "fire",
        percent = 10
      }
    },
    collision_box = {{-0.7, -0.8}, {0.7, 0.8}},
    selection_box = {{-0.7, -0.8}, {0.7, 0.8}},
    rail_category = "regular",
    pictures = railpictures(),
  },
  {
    type = "curved-rail",
    name = "curved-scrap-rail",
    icon = "__base__/graphics/icons/curved-rail.png",
    flags = {"placeable-neutral", "player-creation", "building-direction-8-way"},
    minable = {mining_time = 0.2, result = "scrap-rail", count = 4},
    max_health = 20,
    corpse = "curved-rail-remnants",
    resistances =
    {
      {
        type = "fire",
        percent = 10
      }
    },
    collision_box = {{-0.85, -0.75}, {0.85, 1.6}},
    secondary_collision_box = {{-0.80, -2.38}, {0.80, 2.43}},
    selection_box = {{-1.7, -0.8}, {1.7, 0.8}},
	
    rail_category = "regular",
    pictures = railpictures(),
    placeable_by = { item="scrap-rail", count = 4}
  },
  {
    type = "cargo-wagon",
    name = "ScrapTrailer",
    icon = "__JunkTrain__/graphics/cargo-wagon.png",
    flags = {"placeable-neutral", "player-creation", "placeable-off-grid", "not-on-map"},
    inventory_size = 8,
    minable = {mining_time = 1, result = "ScrapTrailer"},
    mined_sound = {filename = "__core__/sound/deconstruct-medium.ogg"},
    max_health = 6,
    corpse = "medium-remnants",
    dying_explosion = "medium-explosion",
	connection_distance = 3.4,
	joint_distance = 3.4,
	collision_box = {{-0.6, -2.0}, {0.6, 2.0}},
	selection_box = {{-0.7, -2.1}, {1, 2.1}},
	vertical_selection_shift = -0.5,
    weight = 1500,
    max_speed = 0.5,
    braking_force = 3,
    friction_force = 0.50,
    air_resistance = 0.004,
    energy_per_hit_point = 5,
	rail_category = "regular",
	wheels = standard_train_wheels,
    resistances =
    {
      {
        type = "fire",
        decrease = 15,
        percent = 50
      },
    },
    back_light = rolling_stock_back_light(),
    stand_by_light = rolling_stock_stand_by_light(),
    color = {r = 0.43, g = 0.23, b = 0, a = 0.5},
    pictures =
    {
      layers =
            {
                
                {
                    priority = "very-low",
                    width = 256,
                    height = 256,
                    direction_count = 64,
					back_equals_front = true,
                    filenames =
                    {
                        "__JunkTrain__/graphics/cargo-wagon.png",
                    },
                    line_length = 8,
                    lines_per_file = 8,
                    shift = {0.42, -1.125}
                }
            }
    }
	}
})